﻿# $author = T. Butz, 
# $version = summit.2014.07.01
# $url = 'www.thorsten-butz.de'; $twitter = $adn = '@thorstenbutz'

Param
    (
        [Parameter(Mandatory=$false, Position=0)]
        [string]$vmhost,

        [Parameter(Mandatory=$false,Position=1)]
        [string]$vm,

        [Parameter(Mandatory=$false,Position=2)]
        [string]$os,

        [Parameter(Mandatory=$false,Position=3)]
        [int]$niccount=1
    )

# DEFINE VMHOST
if ( $vmhost ){ "VMHost: $vmhost" } else { $vmhost = read-host "HV-Host" }
if ( !($vmhost) ) { $vmhost = "." }

# DEFINE VM-NAME
if ( $vm ){ "VM-Name: $vm" } else { $vm = read-host "VM-Name"}
if ($vm.length -le 2) { Write-Warning "Invalid VM name (at least 3 letters)." ; exit }

# DEFINE OS
if ( $os ){ "OS:$os" } else { $os = read-host "OS [ w81 | ws2012r2 ]"}

$citycode = $vm.substring(0,3)  # 3 letter code, e.g. van,den,per

Import-Module Hyper-V # OPTIONAL

$cpucount = 2					
$startupram = 768MB
$vhdzsize = 300GB
$switch = 'HV_Private1'               # Default virtual switch name
$iso1 = "C:\depot\Unattended\$vm.iso" # Unattended file

if (!(Get-VMSwitch -ComputerName $vmhost -name $switch -ea:0)){ Write-Warning "Hyper-V switch not found: $switch (on $vmhost)" ; exit }
if (Get-VM -ComputerName $vmhost -Name $vm -ea:0){ Write-Warning "VM exists!" ; exit }


switch ($os)
  {
    "w81"      {$iso2 = "C:\Depot\iso\w81eeu1_x64_en.iso"; $iso3= "C:\Depot\iso\rsat_ws2012r2.iso"}
    "ws2012r2" {$iso2 = "C:\Depot\iso\ws2012r2u1en_vl.iso"}
    default    {"OS verification failed." ; exit }
  }


# Check if files exist 
if ($iso1) {
  if (!(Invoke-Command -ComputerName $vmhost -ArgumentList $iso1 { Test-Path $args[0] }))
    {write-warning "File `"$iso1`" not found on: $vmhost" ; exit}
} 

if ($iso2) {
  if (!(Invoke-Command -ComputerName $vmhost -ArgumentList $iso2 { Test-Path $args[0] }))
    {write-warning "File `"$iso2`" not found on: $vmhost" ; exit}
} 

if ($iso3) {
  if (!(Invoke-Command -ComputerName $vmhost -ArgumentList $iso3 { Test-Path $args[0] }))
    {write-warning "File `"$iso3`" not found on: $vmhost" ; exit}
} 


$timestamp = Get-Date -UFormat '%y%m%d'
$vm = $timestamp + '_' + $vm

New-VM `
-ComputerName $vmhost `
–Name $vm `
-MemoryStartupBytes $startupram `
-NewVHDPath "$vm.vhdx" `
-NewvhdSizeBytes $vhdzsize

Set-VM `
-ComputerName $vmhost `
–name $vm `
-ProcessorCount $cpucount `
-DynamicMemory 

Set-VMBios `
-ComputerName $vmhost `
-vmname $vm `
-StartupOrder @("IDE", "CD", "Floppy", "LegacyNetworkAdapter")

Connect-VMNetworkAdapter `
-ComputerName $vmhost `
-VMName $vm `
–SwitchName $switch


if ($niccount -ge 2) {
  Add-VMNetworkAdapter `
  -ComputerName $vmhost `
  -VMName $vm `
  -SwitchName $switch
}

if ($niccount -ge 3) {
  Add-VMNetworkAdapter `
  -ComputerName $vmhost `
  -VMName $vm `
  -SwitchName $switch
}

if ($iso1) {
Set-VMDvdDrive `
-ComputerName $vmhost `
–VMName $vm `
-Path $iso1 
}

if ($iso2) {
Add-VMDvdDrive `
-ComputerName $vmhost `
-VMName $vm `
-Path $iso2 
}

if ($iso3) {
Add-VMDvdDrive `
-ComputerName $vmhost `
-VMName $vm `
-Path $iso3
}


if ($flp) {
# Remove floppy from other VMs 
Get-vm | Get-VMFloppyDiskDrive -ea:0 | Where Path -eq  $flp |
% { Set-VMFloppyDiskDrive $_.vmname $null }

Set-VMFloppyDiskDrive  `
-ComputerName $vmhost `
-VMName $vm `
$flp 
}

Start-VM -ComputerName $vmhost -VMName $vm